Crate galvan_transpiler

Macros

galvan_module
Name of the generated rust module that exports all public items from all galvan files in this crate

Structs

Diagnostic
Represents a single diagnostic message with source location
ErrorCollector
Collects errors and warnings during compilation
Span
Span information for error reporting
TranspileErrors
TranspileOutput

Enums

DiagnosticSeverity
Represents the severity of a diagnostic message
TranspileError
TranspilerError
Main error type for the transpiler

Functions

transpile